@@ -1,9 +1,16 @@
 import pytest
 
+from openapi_spec_validator import OpenAPIV2SpecValidator
+from openapi_spec_validator import OpenAPIV3SpecValidator
+from openapi_spec_validator import OpenAPIV30SpecValidator
+from openapi_spec_validator import OpenAPIV32SpecValidator
 from openapi_spec_validator import openapi_v2_spec_validator
 from openapi_spec_validator import openapi_v30_spec_validator
+from openapi_spec_validator import openapi_v32_spec_validator
+from openapi_spec_validator import validate
 from openapi_spec_validator import validate_spec
 from openapi_spec_validator import validate_spec_url
+from openapi_spec_validator import validate_url
 from openapi_spec_validator.validation.exceptions import OpenAPIValidationError
 from openapi_spec_validator.validation.exceptions import ValidatorDetectError
 
@@ -13,7 +20,7 @@ class TestValidateSpec:
         spec = {}
 
         with pytest.raises(ValidatorDetectError):
-            validate_spec(spec)
+            validate(spec)
 
 
 class TestLocalValidateSpecUrl:
@@ -22,11 +29,10 @@ class TestLocalValidateSpecUrl:
         spec_url = factory.spec_file_url(spec_path)
 
         with pytest.raises(ValidatorDetectError):
-            validate_spec_url(spec_url)
+            validate_url(spec_url)
 
 
 class TestLiocalValidatev2Spec:
-
     LOCAL_SOURCE_DIRECTORY = "data/v2.0/"
 
     def local_test_suite_file_path(self, test_file):
@@ -41,10 +47,11 @@ class TestLiocalValidatev2Spec:
     def test_valid(self, factory, spec_file):
         spec_path = self.local_test_suite_file_path(spec_file)
         spec = factory.spec_from_file(spec_path)
-        spec_url = factory.spec_file_url(spec_path)
 
-        validate_spec(spec)
-        validate_spec(spec, validator=openapi_v2_spec_validator)
+        validate(spec)
+        validate(spec, cls=OpenAPIV2SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            validate_spec(spec, validator=openapi_v2_spec_validator)
 
     @pytest.mark.parametrize(
         "spec_file",
@@ -52,16 +59,18 @@ class TestLiocalValidatev2Spec:
             "empty.yaml",
         ],
     )
-    def test_falied(self, factory, spec_file):
+    def test_failed(self, factory, spec_file):
         spec_path = self.local_test_suite_file_path(spec_file)
         spec = factory.spec_from_file(spec_path)
 
         with pytest.raises(OpenAPIValidationError):
-            validate_spec(spec, validator=openapi_v2_spec_validator)
+            validate(spec, cls=OpenAPIV2SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            with pytest.raises(OpenAPIValidationError):
+                validate_spec(spec, validator=openapi_v2_spec_validator)
 
 
 class TestLocalValidatev30Spec:
-
     LOCAL_SOURCE_DIRECTORY = "data/v3.0/"
 
     def local_test_suite_file_path(self, test_file):
@@ -78,9 +87,12 @@ class TestLocalValidatev30Spec:
         spec = factory.spec_from_file(spec_path)
         spec_url = factory.spec_file_url(spec_path)
 
-        validate_spec(spec)
-        validate_spec(spec, spec_url=spec_url)
-        validate_spec(spec, validator=openapi_v30_spec_validator)
+        validate(spec)
+        with pytest.warns(DeprecationWarning):
+            validate_spec(spec, spec_url=spec_url)
+        validate(spec, cls=OpenAPIV30SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            validate_spec(spec, validator=openapi_v30_spec_validator)
 
     @pytest.mark.parametrize(
         "spec_file",
@@ -88,17 +100,42 @@ class TestLocalValidatev30Spec:
             "empty.yaml",
         ],
     )
-    def test_falied(self, factory, spec_file):
+    def test_failed(self, factory, spec_file):
         spec_path = self.local_test_suite_file_path(spec_file)
         spec = factory.spec_from_file(spec_path)
 
         with pytest.raises(OpenAPIValidationError):
-            validate_spec(spec, validator=openapi_v30_spec_validator)
+            validate(spec, cls=OpenAPIV30SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            with pytest.raises(OpenAPIValidationError):
+                validate_spec(spec, validator=openapi_v30_spec_validator)
+
+
+class TestLocalValidatev32Spec:
+    LOCAL_SOURCE_DIRECTORY = "data/v3.2/"
+
+    def local_test_suite_file_path(self, test_file):
+        return f"{self.LOCAL_SOURCE_DIRECTORY}{test_file}"
+
+    @pytest.mark.parametrize(
+        "spec_file",
+        [
+            "petstore.yaml",
+        ],
+    )
+    def test_valid(self, factory, spec_file):
+        spec_path = self.local_test_suite_file_path(spec_file)
+        spec = factory.spec_from_file(spec_path)
+
+        validate(spec)
+        validate(spec, cls=OpenAPIV3SpecValidator)
+        validate(spec, cls=OpenAPIV32SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            validate_spec(spec, validator=openapi_v32_spec_validator)
 
 
 @pytest.mark.network
 class TestRemoteValidatev2SpecUrl:
-
     REMOTE_SOURCE_URL = (
         "https://raw.githubusercontent.com/OAI/OpenAPI-Specification/"
     )
@@ -120,13 +157,15 @@ class TestRemoteValidatev2SpecUrl:
     def test_valid(self, spec_file):
         spec_url = self.remote_test_suite_file_path(spec_file)
 
-        validate_spec_url(spec_url)
-        validate_spec_url(spec_url, validator=openapi_v2_spec_validator)
+        validate_url(spec_url)
+        validate_url(spec_url, cls=OpenAPIV2SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            validate_spec_url(spec_url)
+            validate_spec_url(spec_url, validator=openapi_v2_spec_validator)
 
 
 @pytest.mark.network
 class TestRemoteValidatev30SpecUrl:
-
     REMOTE_SOURCE_URL = (
         "https://raw.githubusercontent.com/OAI/OpenAPI-Specification/"
     )
@@ -148,5 +187,7 @@ class TestRemoteValidatev30SpecUrl:
     def test_valid(self, spec_file):
         spec_url = self.remote_test_suite_file_path(spec_file)
 
-        validate_spec_url(spec_url)
-        validate_spec_url(spec_url, validator=openapi_v30_spec_validator)
+        validate_url(spec_url)
+        validate_url(spec_url, cls=OpenAPIV30SpecValidator)
+        with pytest.warns(DeprecationWarning):
+            validate_spec_url(spec_url, validator=openapi_v30_spec_validator)
